==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/captchaforms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>CaptchaForms</name>
    <message>
        <source>CAPTCHA Forms</source>
        <translation>CAPTCHA Формы</translation>
    </message>
    <message>
        <source>CAPTCHA Challenges</source>
        <translation>CAPTCHA запросы</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge - %1</source>
        <translation>CAPTCHA запрос - %1</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge</source>
        <translation>CAPTCHA запрос</translation>
    </message>
    <message>
        <source>Describe the sound you hear</source>
        <translation>Опишите звук, который вы слышите</translation>
    </message>
    <message>
        <source>Enter the text you see</source>
        <translation>Введите текст, который вы видите</translation>
    </message>
    <message>
        <source>Answer the question you see</source>
        <translation>Ответьте на вопрос, который вы видите</translation>
    </message>
    <message>
        <source>Identify the picture</source>
        <translation>Опишите рисунок</translation>
    </message>
    <message>
        <source>Answer the question you hear</source>
        <translation>Ответьте на вопрос, который вы слышите</translation>
    </message>
    <message>
        <source>Enter the words you hear</source>
        <translation>Введите слова, которые вы слышите</translation>
    </message>
    <message>
        <source>Answer the question in the video</source>
        <translation>Ответьте на вопрос заданный в видео ролике</translation>
    </message>
    <message>
        <source>Identify the video</source>
        <translation>Опишите видео ролик</translation>
    </message>
    <message>
        <source>You have received the CAPTCHA challenge</source>
        <translation>Вы получили CAPTCHA запрос</translation>
    </message>
    <message>
        <source>Allows to undergo tests on humanity without the use of browser</source>
        <translation>Позволяет проходить тесты на человечность без использования браузера</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/captchaforms.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>CaptchaForms</name>
    <message>
        <source>CAPTCHA Forms</source>
        <translation>CAPTCHA Формы</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge - %1</source>
        <translation>CAPTCHA запрос - %1</translation>
    </message>
    <message>
        <source>CAPTCHA Challenge</source>
        <translation>CAPTCHA запрос</translation>
    </message>
    <message>
        <source>Describe the sound you hear</source>
        <translation>Опишите звук, который вы слышите</translation>
    </message>
    <message>
        <source>Enter the text you see</source>
        <translation>Введите текст, который вы видите</translation>
    </message>
    <message>
        <source>Answer the question you see</source>
        <translation>Ответьте на вопрос, который вы видите</translation>
    </message>
    <message>
        <source>Identify the picture</source>
        <translation>Опишите рисунок</translation>
    </message>
    <message>
        <source>Answer the question you hear</source>
        <translation>Ответьте на вопрос, который вы слышите</translation>
    </message>
    <message>
        <source>Enter the words you hear</source>
        <translation>Введите слова, которые вы слышите</translation>
    </message>
    <message>
        <source>Answer the question in the video</source>
        <translation>Ответьте на вопрос заданный в видео ролике</translation>
    </message>
    <message>
        <source>Identify the video</source>
        <translation>Опишите видео ролик</translation>
    </message>
    <message>
        <source>You have received the CAPTCHA challenge</source>
        <translation>Вы получили CAPTCHA запрос</translation>
    </message>
    <message>
        <source>Allows to undergo tests on humanity without the use of browser</source>
        <translation>Позволяет проходить тесты на человечность без использования браузера</translation>
    </message>
    <message>
        <source>When receiving a CAPTCHA challenge</source>
        <translation>При получении запроса на заполнение CAPTCHA формы</translation>
    </message>
</context>
</TS>
